# myKit

[![Run tests](https://github.com/nvfp/mykit/actions/workflows/run-tests.yml/badge.svg)](https://github.com/nvfp/mykit/actions/workflows/run-tests.yml)
[![pypi version](https://img.shields.io/pypi/v/mykit?logo=pypi)](https://pypi.org/project/mykit/)
[![MIT License](https://img.shields.io/badge/license-MIT-blue.svg?style=flat)](http://choosealicense.com/licenses/mit/)

Python utility toolkit.

The aim of this project is to understand how things work by building them from the ground up, while also providing a lightweight version of something that already exists out there.

<!-- Use this link (don't use the relative path to the one in the repo) to be able to display the banner on PyPI -->
![mykit's banner](https://raw.githubusercontent.com/nvfp/mykit/master/assets/20230619-mykit-banner-360p.png)


## Installation

```sh
pip install mykit
```


## Usage

```python
from mykit.kit.text import byteFmt
from mykit.app.arrow import Arrow
from mykit.app.slider import Slider


x = byteFmt(3141592653589793)
print(x)  # 2.79 PiB
```


## Links

- [Documentation](https://nvfp.github.io/mykit)
- [Demo](https://nvfp.github.io/mykit/demo)
- [Supports💙](https://nvfp.github.io/many-thanks)
- [Changelog](https://nvfp.github.io/mykit/changelog)
- [FAQs](https://nvfp.github.io/mykit/faqs)


## Troubleshoot

- To report bugs or ask questions, please open an issue or submit a pull request.


## License

This project is licensed under the MIT license.
